@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.1.8';
+our $VERSION = '0.1.9';
 
 1;
 
@@ -1393,17 +1393,19 @@ C<match_l> - In a suite runner output truncate matching strings to {match_l} byt
 
 C<SPARROW_ROOT> - if set, used as prefix for test root directory.
 
-  +---------------------+----------------------+
-  | Test root directory | SPARROWI<ROOT Is Set? |
-  +---------------------+----------------------+
-  | /tmp/.outthentic    | No                   |
-  | $SPARROW>ROOT/tmp/  | Yes                  |
-  +---------------------+----------------------+
-
 
 
 =back
 
+Test root directory resolution table:
+
+    +---------------------+----------------------+
+    | Test root directory | SPARROW_ROOT Is Set? |
+    +---------------------+----------------------+
+    | /tmp/.outthentic    | No                   |
+    | $SPARROW_ROOT/tmp/  | Yes                  |
+    +---------------------+----------------------+
+
 
 =head1 Examples
 
